==> osmo_0.2.4.orig.tar.gz: osmo-0.2.4/src/stock_icons.h <==

/*
 * Osmo - a handy personal organizer
 *
 * Copyright (C) 2007 Tomasz Maka <pasp@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef _STOCK_ICONS_H
#define _STOCK_ICONS_H

#include "gui.h"

#define     OSMO_STOCK_BUTTON_ADD               "osmo-button-add"
#define     OSMO_STOCK_BUTTON_CLEAR             "osmo-button-clear"
#define     OSMO_STOCK_BUTTON_CLOSE             "osmo-button-close"
#define     OSMO_STOCK_BUTTON_CANCEL            "osmo-button-cancel"
#define     OSMO_STOCK_BUTTON_JUMPTO            "osmo-button-jumpto"
#define     OSMO_STOCK_BUTTON_CONTACTS_EXPORT   "osmo-button-contacts-export"
#define     OSMO_STOCK_BUTTON_CONTACTS_IMPORT   "osmo-button-contacts-import"
#define     OSMO_STOCK_BUTTON_EDIT              "osmo-button-edit"
#define     OSMO_STOCK_BUTTON_INFO              "osmo-button-info"
#define     OSMO_STOCK_BUTTON_INSERT_TIMELINE   "osmo-button-insert_timeline"
#define     OSMO_STOCK_BUTTON_NEXT_YEAR         "osmo-button-next_year"
#define     OSMO_STOCK_BUTTON_NO                "osmo-button-no"
#define     OSMO_STOCK_BUTTON_OK                "osmo-button-ok"
#define     OSMO_STOCK_BUTTON_OPEN              "osmo-button-open"
#define     OSMO_STOCK_BUTTON_PREV_YEAR         "osmo-button-prev_year"
#define     OSMO_STOCK_BUTTON_REMOVE            "osmo-button-remove"
#define     OSMO_STOCK_BUTTON_SELECT_COLOR      "osmo-button-select_color"
#define     OSMO_STOCK_BUTTON_SELECT_DATE       "osmo-button-select_date"
#define     OSMO_STOCK_BUTTON_SELECT_FONT       "osmo-button-select_font"
#define     OSMO_STOCK_BUTTON_TODAY             "osmo-button-today"
#define     OSMO_STOCK_BUTTON_YES               "osmo-button-yes"

#define     OSMO_STOCK_SYSTRAY_BIRTHDAY         "osmo-systray-birthday"
#define     OSMO_STOCK_SYSTRAY_NORMAL           "osmo-systray-normal"
#define     OSMO_STOCK_SYSTRAY_TASK             "osmo-systray-task"

#define     OSMO_STOCK_ABOUT                    "osmo-about"
#define     OSMO_STOCK_CALENDAR                 "osmo-calendar"
#define     OSMO_STOCK_CLOSE                    "osmo-close"
#define     OSMO_STOCK_CALCULATOR               "osmo-calculator"
#define     OSMO_STOCK_CONTACTS_ADD             "osmo-contacts-add"
#define     OSMO_STOCK_CONTACTS_BIRTHDAYS       "osmo-contacts-birthdays"
#define     OSMO_STOCK_CONTACTS_EDIT            "osmo-contacts-edit"
#define     OSMO_STOCK_CONTACTS_EXPORT          "osmo-contacts-export"
#define     OSMO_STOCK_CONTACTS_IMPORT          "osmo-contacts-import"
#define     OSMO_STOCK_CONTACTS_REMOVE          "osmo-contacts-remove"
#define     OSMO_STOCK_CONTACTS                 "osmo-contacts"
#define     OSMO_STOCK_EDIT_NOTE                "osmo-edit_note"
#define     OSMO_STOCK_EDITOR_BOLD              "osmo-editor-bold"
#define     OSMO_STOCK_EDITOR_CLEAR             "osmo-editor-clear"
#define     OSMO_STOCK_EDITOR_FIND              "osmo-editor-find"
#define     OSMO_STOCK_EDITOR_HIGHLIGHT         "osmo-editor-highlight"
#define     OSMO_STOCK_EDITOR_INFO              "osmo-editor-info"
#define     OSMO_STOCK_EDITOR_INSERT_DATE_TIME  "osmo-editor-insert_date_time"
#define     OSMO_STOCK_EDITOR_INSERT_SEPARATOR  "osmo-editor-insert_separator"
#define     OSMO_STOCK_EDITOR_ITALIC            "osmo-editor-italic"
#define     OSMO_STOCK_EDITOR_SAVE              "osmo-editor-save"
#define     OSMO_STOCK_EDITOR_STRIKETHROUGH     "osmo-editor-strikethrough"
#define     OSMO_STOCK_EDITOR_UNDERLINE         "osmo-editor-underline"
#define     OSMO_STOCK_FULLYEAR                 "osmo-fullyear"
#define     OSMO_STOCK_HELP                     "osmo-help"
#define     OSMO_STOCK_JUMPTO                   "osmo-jumpto"
#define     OSMO_STOCK_LICENSE                  "osmo-license"
#define     OSMO_STOCK_LIST_INVALID             "osmo-list-invalid"
#define     OSMO_STOCK_LIST_VALID               "osmo-list-valid"
#define     OSMO_STOCK_NEXT_DAY                 "osmo-next-day"
#define     OSMO_STOCK_NEXT_MONTH               "osmo-next-month"
#define     OSMO_STOCK_NEXT_YEAR                "osmo-next-year"
#define     OSMO_STOCK_NOTES_ADD                "osmo-notes-add"
#define     OSMO_STOCK_NOTES_EDIT               "osmo-notes-edit"
#define     OSMO_STOCK_NOTES_REMOVE             "osmo-notes-remove"
#define     OSMO_STOCK_NOTES                    "osmo-notes"
#define     OSMO_STOCK_PREFERENCES              "osmo-preferences"
#define     OSMO_STOCK_PREV_DAY                 "osmo-prev-day"
#define     OSMO_STOCK_PREV_MONTH               "osmo-prev-month"
#define     OSMO_STOCK_PREV_YEAR                "osmo-prev-year"
#define     OSMO_STOCK_TASKS_ADD                "osmo-tasks-add"
#define     OSMO_STOCK_TASKS_EDIT               "osmo-tasks-edit"
#define     OSMO_STOCK_TASKS_REMOVE             "osmo-tasks-remove"
#define     OSMO_STOCK_TASKS_PREV_DAY           "osmo-tasks-prev-day"
#define     OSMO_STOCK_TASKS_NEXT_DAY           "osmo-tasks-next-day"
#define     OSMO_STOCK_TASKS_TYPE_NORMAL        "osmo-tasks-type-normal"
#define     OSMO_STOCK_TASKS_TYPE_RECURRENT     "osmo-tasks-type-recurrent"
#define     OSMO_STOCK_TASKS                    "osmo-tasks"
#define     OSMO_STOCK_TODAY                    "osmo-today"
#define     OSMO_STOCK_PRINT                    "osmo-print"

void    osmo_register_stock_icons   (void);

#endif /* _STOCK_ICONS_H */

==> osmo_0.2.6.orig.tar.gz: osmo-0.2.6/src/stock_icons.h <==

/*
 * Osmo - a handy personal organizer
 *
 * Copyright (C) 2007 Tomasz Maka <pasp@users.sourceforge.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifndef _STOCK_ICONS_H
#define _STOCK_ICONS_H

#include "gui.h"

#define     OSMO_STOCK_BUTTON_ADD               "osmo-button-add"
#define     OSMO_STOCK_BUTTON_CLEAR             "osmo-button-clear"
#define     OSMO_STOCK_BUTTON_CLOSE             "osmo-button-close"
#define     OSMO_STOCK_BUTTON_CANCEL            "osmo-button-cancel"
#define     OSMO_STOCK_BUTTON_JUMPTO            "osmo-button-jumpto"
#define     OSMO_STOCK_BUTTON_CONTACTS_EXPORT   "osmo-button-contacts-export"
#define     OSMO_STOCK_BUTTON_CONTACTS_IMPORT   "osmo-button-contacts-import"
#define     OSMO_STOCK_BUTTON_EDIT              "osmo-button-edit"
#define     OSMO_STOCK_BUTTON_DOWN              "osmo-button-down"
#define     OSMO_STOCK_BUTTON_INFO              "osmo-button-info"
#define     OSMO_STOCK_BUTTON_INSERT_TIMELINE   "osmo-button-insert_timeline"
#define     OSMO_STOCK_BUTTON_NEXT_YEAR         "osmo-button-next_year"
#define     OSMO_STOCK_BUTTON_NO                "osmo-button-no"
#define     OSMO_STOCK_BUTTON_OK                "osmo-button-ok"
#define     OSMO_STOCK_BUTTON_OPEN              "osmo-button-open"
#define     OSMO_STOCK_BUTTON_PREV_YEAR         "osmo-button-prev_year"
#define     OSMO_STOCK_BUTTON_REMOVE            "osmo-button-remove"
#define     OSMO_STOCK_BUTTON_SELECT_COLOR      "osmo-button-select_color"
#define     OSMO_STOCK_BUTTON_SELECT_DATE       "osmo-button-select_date"
#define     OSMO_STOCK_BUTTON_SELECT_FONT       "osmo-button-select_font"
#define     OSMO_STOCK_BUTTON_TODAY             "osmo-button-today"
#define     OSMO_STOCK_BUTTON_YES               "osmo-button-yes"

#define     OSMO_STOCK_SYSTRAY_BIRTHDAY         "osmo-systray-birthday"
#define     OSMO_STOCK_SYSTRAY_NORMAL           "osmo-systray-normal"
#define     OSMO_STOCK_SYSTRAY_NOTE             "osmo-systray-note"
#define     OSMO_STOCK_SYSTRAY_TASK             "osmo-systray-task"
#define     OSMO_STOCK_SYSTRAY_MENU_CALENDAR    "osmo-systray-menu-calendar"
#define     OSMO_STOCK_SYSTRAY_MENU_TASKS       "osmo-systray-menu-tasks"
#define     OSMO_STOCK_SYSTRAY_MENU_CONTACTS    "osmo-systray-menu-contacts"
#define     OSMO_STOCK_SYSTRAY_MENU_NOTES       "osmo-systray-menu-notes"

#define     OSMO_STOCK_ABOUT                    "osmo-about"
#define     OSMO_STOCK_CALENDAR                 "osmo-calendar"
#define     OSMO_STOCK_CLOSE                    "osmo-close"
#define     OSMO_STOCK_CALCULATOR               "osmo-calculator"
#define     OSMO_STOCK_CONTACTS_ADD             "osmo-contacts-add"
#define     OSMO_STOCK_CONTACTS_BIRTHDAYS       "osmo-contacts-birthdays"
#define     OSMO_STOCK_CONTACTS_EDIT            "osmo-contacts-edit"
#define     OSMO_STOCK_CONTACTS_EXPORT          "osmo-contacts-export"
#define     OSMO_STOCK_CONTACTS_IMPORT          "osmo-contacts-import"
#define     OSMO_STOCK_CONTACTS_MAP_LOCATION    "osmo-contacts-map_location"
#define     OSMO_STOCK_CONTACTS_REMOVE          "osmo-contacts-remove"
#define     OSMO_STOCK_CONTACTS                 "osmo-contacts"
#define     OSMO_STOCK_EDIT_NOTE                "osmo-edit_note"
#define     OSMO_STOCK_EDITOR_BOLD              "osmo-editor-bold"
#define     OSMO_STOCK_EDITOR_CLEAR             "osmo-editor-clear"
#define     OSMO_STOCK_EDITOR_FIND              "osmo-editor-find"
#define     OSMO_STOCK_EDITOR_HIGHLIGHT         "osmo-editor-highlight"
#define     OSMO_STOCK_EDITOR_INFO              "osmo-editor-info"
#define     OSMO_STOCK_EDITOR_INSERT_DATE_TIME  "osmo-editor-insert_date_time"
#define     OSMO_STOCK_EDITOR_INSERT_SEPARATOR  "osmo-editor-insert_separator"
#define     OSMO_STOCK_EDITOR_ITALIC            "osmo-editor-italic"
#define     OSMO_STOCK_EDITOR_SAVE              "osmo-editor-save"
#define     OSMO_STOCK_EDITOR_SPELL_CHECKER     "osmo-editor-spell_checker"
#define     OSMO_STOCK_EDITOR_STRIKETHROUGH     "osmo-editor-strikethrough"
#define     OSMO_STOCK_EDITOR_UNDERLINE         "osmo-editor-underline"
#define     OSMO_STOCK_FULLYEAR                 "osmo-fullyear"
#define     OSMO_STOCK_HELP                     "osmo-help"
#define     OSMO_STOCK_INFO_HELP                "osmo-info-help"
#define     OSMO_STOCK_JUMPTO                   "osmo-jumpto"
#define     OSMO_STOCK_LICENSE                  "osmo-license"
#define     OSMO_STOCK_LIST_INVALID             "osmo-list-invalid"
#define     OSMO_STOCK_LIST_VALID               "osmo-list-valid"
#define     OSMO_STOCK_NEXT_DAY                 "osmo-next-day"
#define     OSMO_STOCK_NEXT_MONTH               "osmo-next-month"
#define     OSMO_STOCK_NEXT_YEAR                "osmo-next-year"
#define     OSMO_STOCK_NOTES_ADD                "osmo-notes-add"
#define     OSMO_STOCK_NOTES_EDIT               "osmo-notes-edit"
#define     OSMO_STOCK_NOTES_REMOVE             "osmo-notes-remove"
#define     OSMO_STOCK_NOTES                    "osmo-notes"
#define     OSMO_STOCK_PREFERENCES              "osmo-preferences"
#define     OSMO_STOCK_PREV_DAY                 "osmo-prev-day"
#define     OSMO_STOCK_PREV_MONTH               "osmo-prev-month"
#define     OSMO_STOCK_PREV_YEAR                "osmo-prev-year"
#define     OSMO_STOCK_TASKS_ADD                "osmo-tasks-add"
#define     OSMO_STOCK_TASKS_EDIT               "osmo-tasks-edit"
#define     OSMO_STOCK_TASKS_REMOVE             "osmo-tasks-remove"
#define     OSMO_STOCK_TASKS_PREV_DAY           "osmo-tasks-prev-day"
#define     OSMO_STOCK_TASKS_NEXT_DAY           "osmo-tasks-next-day"
#define     OSMO_STOCK_TASKS                    "osmo-tasks"
#define     OSMO_STOCK_TODAY                    "osmo-today"
#define     OSMO_STOCK_PRINT                    "osmo-print"

#define     OSMO_STOCK_TYPE_NORMAL              "osmo-type-normal"
#define     OSMO_STOCK_TYPE_ENCRYPTED           "osmo-type-encrypted"
#define     OSMO_STOCK_TYPE_RECURRENT           "osmo-type-recurrent"
#define     OSMO_STOCK_TYPE_RECURRENT_INACTIVE  "osmo-type-recurrent-inactive"

void    osmo_register_stock_icons   (void);

#endif /* _STOCK_ICONS_H */
